pub struct CompiledPolicy {
pub hidden_file_policy: HiddenFilePolicy,
pub symlink_policy: SymlinkPolicy,
pub max_file_size_bytes: Option<u64>,
/* private fields */
}Expand description
A source policy compiled for fast per-entry checks.
Fields
symlink_policy: SymlinkPolicymax_file_size_bytes: Option<u64>Implementations
Sourceimpl CompiledPolicy
impl CompiledPolicy
Sourcepub fn from_source(source: &SourceRecord) -> Self
pub fn from_source(source: &SourceRecord) -> Self
Compile from a catalog source record. The default excludes are always active in addition to user excludes.
Sourcepub fn component_excluded(&self, name: &str) -> bool
pub fn component_excluded(&self, name: &str) -> bool
Whether a directory or file component is excluded by name.
Whether a component is hidden (dotfile convention).
Sourcepub fn file_included(&self, file_name: &str) -> bool
pub fn file_included(&self, file_name: &str) -> bool
Whether a file name passes the include/exclude pattern rules.
Sourcepub fn size_allowed(&self, size: u64) -> bool
pub fn size_allowed(&self, size: u64) -> bool
Whether a file size is within the policy limit.